@@ -33,6 +33,9 @@ LOG = logging.getLogger(__name__)
 
 
 def write_default_ansible_cfg(work_dir,
+                              remote_user,
+                              ssh_private_key=None,
+                              transport=None,
                               base_ansible_cfg='/etc/ansible/ansible.cfg'):
     ansible_config_path = os.path.join(work_dir, 'ansible.cfg')
     shutil.copy(base_ansible_cfg, ansible_config_path)
@@ -44,15 +47,27 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'log_path',
                os.path.join(work_dir, 'ansible.log'))
     config.set('defaults', 'forks', '25')
+    config.set('defaults', 'timeout', '30')
 
     # mistral user has no home dir set, so no place to save a known hosts file
     config.set('ssh_connection', 'ssh_args',
                '-o UserKnownHostsFile=/dev/null '
                '-o StrictHostKeyChecking=no '
                '-o ControlMaster=auto '
-               '-o ControlPersist=60s')
+               '-o ControlPersist=30m')
     config.set('ssh_connection', 'control_path_dir',
                os.path.join(work_dir, 'ansible-ssh'))
+    config.set('ssh_connection', 'retries', '8')
+    config.set('ssh_connection', 'pipelining', 'True')
+
+    # Set connection info in config file so that subsequent/nested ansible
+    # calls can re-use it
+    if remote_user:
+        config.set('defaults', 'remote_user', remote_user)
+    if ssh_private_key:
+        config.set('defaults', 'private_key_file', ssh_private_key)
+    if transport:
+        config.set('defaults', 'transport', transport)
 
     with open(ansible_config_path, 'w') as configfile:
         config.write(configfile)
@@ -171,9 +186,6 @@ class AnsibleAction(actions.Action):
         if self.limit_hosts:
             command.extend(['--limit', self.limit_hosts])
 
-        if self.remote_user:
-            command.extend(['--user', self.remote_user])
-
         if self.become:
             command.extend(['--become'])
 
@@ -198,9 +210,6 @@ class AnsibleAction(actions.Action):
         if self.inventory:
             command.extend(['--inventory-file', self.inventory])
 
-        if self.ssh_private_key:
-            command.extend(['--private-key', self.ssh_private_key])
-
         if self.extra_env_variables:
             if not isinstance(self.extra_env_variables, dict):
                 msg = "extra_env_variables must be a dict"
@@ -210,9 +219,13 @@ class AnsibleAction(actions.Action):
             command.extend(['--gather-facts', self.gather_facts])
 
         try:
-            ansible_config_path = write_default_ansible_cfg(self.work_dir)
+            ansible_config_path = write_default_ansible_cfg(
+                self.work_dir,
+                self.remote_user,
+                ssh_private_key=self.ssh_private_key)
             env_variables = {
                 'HOME': self.work_dir,
+                'ANSIBLE_LOCAL_TEMP': self.work_dir,
                 'ANSIBLE_CONFIG': ansible_config_path
             }
 
@@ -287,6 +300,11 @@ class AnsiblePlaybookAction(base.TripleOAction):
             'max_message_size', 1048576)
         self.gather_facts = self._kwargs_for_run.pop('gather_facts', False)
         self.trash_output = self._kwargs_for_run.pop('trash_output', False)
+        self.profile_tasks = self._kwargs_for_run.pop('profile_tasks', True)
+        self.profile_tasks_limit = self._kwargs_for_run.pop(
+            'profile_tasks_limit', 0)
+        self.blacklisted_hostnames = self._kwargs_for_run.pop(
+            'blacklisted_hostnames', [])
 
     @property
     def work_dir(self):
@@ -413,9 +431,6 @@ class AnsiblePlaybookAction(base.TripleOAction):
         if self.module_path:
             command.extend(['--module-path', self.module_path])
 
-        if self.remote_user:
-            command.extend(['--user', self.remote_user])
-
         if self.become:
             command.extend(['--become'])
 
@@ -443,8 +458,10 @@ class AnsiblePlaybookAction(base.TripleOAction):
         if self.inventory:
             command.extend(['--inventory-file', self.inventory])
 
-        if self.ssh_private_key:
-            command.extend(['--private-key', self.ssh_private_key])
+        if self.blacklisted_hostnames:
+            host_pattern = ':'.join(
+                ['!%s' % h for h in self.blacklisted_hostnames])
+            command.extend(['--limit', host_pattern])
 
         if self.tags:
             command.extend(['--tags', self.tags])
@@ -464,12 +481,25 @@ class AnsiblePlaybookAction(base.TripleOAction):
             command.extend(['--gather-facts', self.gather_facts])
 
         try:
-            ansible_config_path = write_default_ansible_cfg(self.work_dir)
+            ansible_config_path = write_default_ansible_cfg(
+                self.work_dir,
+                self.remote_user,
+                ssh_private_key=self.ssh_private_key)
             env_variables = {
                 'HOME': self.work_dir,
-                'ANSIBLE_CONFIG': ansible_config_path
+                'ANSIBLE_LOCAL_TEMP': self.work_dir,
+                'ANSIBLE_CONFIG': ansible_config_path,
             }
 
+            if self.profile_tasks:
+                env_variables.update({
+                    # the whitelist could be collected from multiple
+                    # arguments if we find a use case for it
+                    'ANSIBLE_CALLBACK_WHITELIST': 'profile_tasks',
+                    'PROFILE_TASKS_TASK_OUTPUT_LIMIT':
+                        six.text_type(self.profile_tasks_limit),
+                })
+
             if self.extra_env_variables:
                 env_variables.update(self.extra_env_variables)
 
