@@ -46,7 +46,7 @@ class RegisterOrUpdateNodes(base.TripleOAction):
     def __init__(self, nodes_json, remove=False, kernel_name=None,
                  ramdisk_name=None, instance_boot_option='local'):
         super(RegisterOrUpdateNodes, self).__init__()
-        self.nodes_json = nodes_json
+        self.nodes_json = nodes.convert_nodes_json_mac_to_ports(nodes_json)
         self.remove = remove
         self.instance_boot_option = instance_boot_option
         self.kernel_name = kernel_name
@@ -83,7 +83,7 @@ class ValidateNodes(base.TripleOAction):
 
     def __init__(self, nodes_json):
         super(ValidateNodes, self).__init__()
-        self.nodes_json = nodes_json
+        self.nodes_json = nodes.convert_nodes_json_mac_to_ports(nodes_json)
 
     def run(self, context):
         try:
@@ -152,6 +152,16 @@ class ConfigureBootAction(base.TripleOAction):
                     'path': '/driver_info/deploy_kernel',
                     'value': image_ids['kernel'],
                 },
+                {
+                    'op': 'add',
+                    'path': '/driver_info/rescue_ramdisk',
+                    'value': image_ids['ramdisk'],
+                },
+                {
+                    'op': 'add',
+                    'path': '/driver_info/rescue_kernel',
+                    'value': image_ids['kernel'],
+                },
             ])
             LOG.debug("Configuring boot option for Node %s", self.node_uuid)
         except Exception as err:
