@@ -33,7 +33,7 @@ class TestActionsBase(tests_base.TestCase):
         self.action = base.TripleOAction()
 
     @mock.patch.object(ironicclient, 'Client')
-    def test__get_baremetal_client(self, mock_client, mock_endpoint):
+    def test_get_baremetal_client(self, mock_client, mock_endpoint):
         mock_cxt = mock.MagicMock()
         mock_endpoint.return_value = mock.Mock(
             url='http://ironic/v1', region='ironic-region')
@@ -41,7 +41,7 @@ class TestActionsBase(tests_base.TestCase):
         mock_client.assert_called_once_with(
             'http://ironic/v1', max_retries=12, os_ironic_api_version='1.36',
             region_name='ironic-region', retry_interval=5, token=mock.ANY)
-        mock_endpoint.assert_called_once_with(mock_cxt, 'ironic')
+        mock_endpoint.assert_called_once_with(mock_cxt.security, 'ironic')
         mock_cxt.assert_not_called()
 
     def test_cache_key(self, mock_endpoint):
