@@ -30,12 +30,12 @@ from tripleo_common.tests.image import fakes
 
 filedata = six.u(
     """container_images:
-    - imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
+    - imagename: docker.io/tripleorocky/heat-docker-agents-centos:latest
       push_destination: localhost:8787
-    - imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
+    - imagename: docker.io/tripleorocky/centos-binary-nova-compute:liberty
       push_destination: localhost:8787
-    - imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
-    - imagename: docker.io/tripleomaster/image-with-missing-tag
+    - imagename: docker.io/tripleorocky/centos-binary-nova-libvirt:liberty
+    - imagename: docker.io/tripleorocky/image-with-missing-tag
       push_destination: localhost:8787
 """)
 
@@ -76,22 +76,22 @@ class TestImageUploadManager(base.TestCase):
 
         dockerc = mockdocker.return_value
         dockerc.remove_image.assert_has_calls([
-            mock.call('192.0.2.0:8787/tripleomaster'
+            mock.call('192.0.2.0:8787/tripleorocky'
                       '/centos-binary-nova-libvirt:liberty'),
-            mock.call('docker.io/tripleomaster'
+            mock.call('docker.io/tripleorocky'
                       '/centos-binary-nova-compute:liberty'),
-            mock.call('docker.io/tripleomaster'
+            mock.call('docker.io/tripleorocky'
                       '/centos-binary-nova-libvirt:liberty'),
-            mock.call('docker.io/tripleomaster'
+            mock.call('docker.io/tripleorocky'
                       '/heat-docker-agents-centos:latest'),
-            mock.call('docker.io/tripleomaster'
+            mock.call('docker.io/tripleorocky'
                       '/image-with-missing-tag:latest'),
 
-            mock.call('localhost:8787/tripleomaster'
+            mock.call('localhost:8787/tripleorocky'
                       '/centos-binary-nova-compute:liberty'),
-            mock.call('localhost:8787/tripleomaster'
+            mock.call('localhost:8787/tripleorocky'
                       '/heat-docker-agents-centos:latest'),
-            mock.call('localhost:8787/tripleomaster/'
+            mock.call('localhost:8787/tripleorocky/'
                       'image-with-missing-tag:latest'),
         ])
 
@@ -188,14 +188,14 @@ class TestDockerImageUploader(base.TestCase):
         mock_process.returncode = 0
         mock_popen.return_value = mock_process
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        push_image = 'localhost:8787/tripleorocky/heat-docker-agents-centos'
 
         self.assertEqual(
-            ['docker.io/tripleomaster/heat-docker-agents-centos:latest',
-             'localhost:8787/tripleomaster/heat-docker-agents-centos:latest'],
+            ['docker.io/tripleorocky/heat-docker-agents-centos:latest',
+             'localhost:8787/tripleorocky/heat-docker-agents-centos:latest'],
             self.uploader.upload_image(
                 image + ':' + tag,
                 None,
@@ -224,10 +224,10 @@ class TestDockerImageUploader(base.TestCase):
 
     @mock.patch('subprocess.Popen')
     def test_upload_image_missing_tag(self, mock_popen):
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
         expected_tag = 'latest'
         push_destination = 'localhost:8787'
-        push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        push_image = 'localhost:8787/tripleorocky/heat-docker-agents-centos'
 
         self.uploader.upload_image(image,
                                    None,
@@ -261,7 +261,7 @@ class TestDockerImageUploader(base.TestCase):
         mock_process.communicate.return_value = (json.dumps(result), '')
         mock_process.returncode = 0
         mock_popen.return_value = mock_process
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
 
@@ -297,11 +297,11 @@ class TestDockerImageUploader(base.TestCase):
         mock_process.returncode = 1
         mock_popen.return_value = mock_process
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
         tag = 'latest'
         append_tag = 'modify-123'
         push_destination = 'localhost:8787'
-        push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        push_image = 'localhost:8787/tripleorocky/heat-docker-agents-centos'
         playbook = [{
             'tasks': [{
                 'import_role': {
@@ -320,7 +320,7 @@ class TestDockerImageUploader(base.TestCase):
 
         # test response for a partial cleanup
         self.assertEqual(
-            ['docker.io/tripleomaster/heat-docker-agents-centos:latest'],
+            ['docker.io/tripleorocky/heat-docker-agents-centos:latest'],
             self.uploader.upload_image(
                 image + ':' + tag,
                 None,
@@ -357,7 +357,7 @@ class TestDockerImageUploader(base.TestCase):
         mock_process.returncode = 1
         mock_popen.return_value = mock_process
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
         tag = 'latest'
         append_tag = 'modify-123'
         push_destination = 'localhost:8787'
@@ -387,7 +387,7 @@ class TestDockerImageUploader(base.TestCase):
         mock_process = mock.Mock()
         mock_popen.return_value = mock_process
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
         tag = 'latest'
         append_tag = 'modify-123'
         push_destination = 'localhost:8787'
@@ -416,7 +416,7 @@ class TestDockerImageUploader(base.TestCase):
     def test_modify_image_existing(self, mock_ansible, mock_inspect):
         mock_inspect.return_value = {'Digest': 'a'}
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
         tag = 'latest'
         append_tag = 'modify-123'
         push_destination = 'localhost:8787'
@@ -636,7 +636,7 @@ class TestDockerImageUploader(base.TestCase):
     @mock.patch('tenacity.wait.wait_random_exponential.__call__')
     def test_pull_retry(self, mock_wait):
         mock_wait.return_value = 0
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
 
         dockerc = self.dockermock.return_value
         dockerc.pull.side_effect = [
@@ -656,7 +656,7 @@ class TestDockerImageUploader(base.TestCase):
     @mock.patch('tenacity.wait.wait_random_exponential.__call__')
     def test_pull_retry_failure(self, mock_wait):
         mock_wait.return_value = 0
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
 
         dockerc = self.dockermock.return_value
         dockerc.pull.side_effect = [
